@@ -1,25 +1,37 @@
-/* Libvoikko: Finnish spellchecker and hyphenator library
- * Copyright (C) 2008 - 2010 Harri Pitkänen <hatapitk@iki.fi>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+/* The contents of this file are subject to the Mozilla Public License Version 
+ * 1.1 (the "License"); you may not use this file except in compliance with 
+ * the License. You may obtain a copy of the License at 
+ * http://www.mozilla.org/MPL/
+ * 
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ * 
+ * The Original Code is Libvoikko: Library of natural language processing tools.
+ * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
+ * Portions created by the Initial Developer are Copyright (C) 2008 - 2012
+ * the Initial Developer. All Rights Reserved.
+ * 
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
  *********************************************************************************/
 
-#include "grammar/error.hpp"
+#include "grammar/VoikkoGrammarError.hpp"
 #include "porting.h"
+#include "utils/StringUtils.hpp"
 #include <cstring>
 
+
 namespace libvoikko {
 
 VOIKKOEXPORT const char * voikko_error_message_cstr(int error_code, const char * language) {
@@ -60,6 +72,8 @@ VOIKKOEXPORT const char * voikko_error_message_cstr(int error_code, const char *
 				return "Sidesana (ja, tai, mutta, ...) ei voi olla virkkeen viimeinen sana.";
 			case GCERR_MISSING_MAIN_VERB:
 				return "Tarkista, puuttuuko virkkeest\xc3\xa4 p\xc3\xa4\xc3\xa4verbi tai -verbej\xc3\xa4.";
+			case GCERR_EXTRA_MAIN_VERB:
+				return "Virkkeest\xc3\xa4 saattaa puuttua pilkku, tai siin\xc3\xa4 voi olla ylim\xc3\xa4\xc3\xa4r\xc3\xa4inen verbi.";
 		}
 		return "Tuntematon virhe";
 	}
@@ -99,18 +113,16 @@ VOIKKOEXPORT const char * voikko_error_message_cstr(int error_code, const char *
 				return "Sentence should not end with a conjunction.";
 			case GCERR_MISSING_MAIN_VERB:
 				return "Sentence should contain one or more main verbs.";
+			case GCERR_EXTRA_MAIN_VERB:
+				return "Check if sentence contains unnecessary verbs or if a comma is missing.";
 		}
 		return "Unknown error";
 	}
 }
 
-void init_grammar_error(voikko_grammar_error * error) {
-	error->error_code = 0;
-	error->error_level = 0;
-	error->error_description = 0;
-	error->startpos = 0;
-	error->errorlen = 0;
-	error->suggestions = 0;
+VOIKKOEXPORT const char * voikkoGetGrammarErrorShortDescription(const grammar::VoikkoGrammarError * error, const char * language) {
+	return utils::StringUtils::copy(voikko_error_message_cstr(error->getErrorCode(), language));
 }
 
+
 }
