@@ -29,7 +29,7 @@
 #include <cstring>
 #include <set>
 #include "setup/Dictionary.hpp"
-#include "setup/DictionaryLoader.hpp"
+#include "setup/DictionaryFactory.hpp"
 #include "porting.h"
 
 using namespace std;
@@ -38,10 +38,14 @@ namespace libvoikko { namespace setup {
 
 typedef Dictionary voikko_dict;
 
+static const int CAPABILITY_SPELL = 1;
+static const int CAPABILITY_GC = 2;
+static const int CAPABILITY_HYPHENATION = 4;
+
 VOIKKOEXPORT voikko_dict ** voikko_list_dicts(const char * path) {
 	list<Dictionary> dictList = path ?
-	                            DictionaryLoader::findAllAvailable(path) :
-	                            DictionaryLoader::findAllAvailable();
+	                            DictionaryFactory::findAllAvailable(path) :
+	                            DictionaryFactory::findAllAvailable();
 	
 	voikko_dict ** dicts = new voikko_dict*[dictList.size() + 1];
 	size_t n = 0;
@@ -63,21 +67,44 @@ VOIKKOEXPORT const char * voikko_dict_language(const voikko_dict * dict) {
 	return dict->getLanguage().getLanguage().c_str();
 }
 
+VOIKKOEXPORT const char * voikko_dict_script(const voikko_dict * dict) {
+	return dict->getLanguage().getScript().c_str();
+}
+
 VOIKKOEXPORT const char * voikko_dict_variant(const voikko_dict * dict) {
-	return dict->getLanguage().getPrivateUse().c_str();
+	const char * variant = dict->getLanguage().getPrivateUse().c_str();
+	if (variant && variant[0] != '\0') {
+		return variant;
+	}
+	return "standard";
 }
 
 VOIKKOEXPORT const char * voikko_dict_description(const voikko_dict * dict) {
 	return dict->getDescription().c_str();
 }
 
-VOIKKOEXPORT char ** voikkoListSupportedSpellingLanguages(const char * path) {
+static string getShortLangForCapabilityFilteredList(LanguageTag langTag) {
+	if (langTag.getScript() == "") {
+		return langTag.getLanguage();
+	}
+	// TODO script should not be appended  if it is not strictly needed,
+	// For now we just trust the dictionary maintainers to do the right thing.
+	return langTag.getLanguage() + "-" + langTag.getScript();
+}
+
+// TODO: implement filtering by capability
+static char ** listSupportedLanguagesForCapability(const char * path, int capability) {
 	list<Dictionary> dictList = path ?
-	                            DictionaryLoader::findAllAvailable(path) :
-	                            DictionaryLoader::findAllAvailable();
+	                            DictionaryFactory::findAllAvailable(path) :
+	                            DictionaryFactory::findAllAvailable();
 	set<string> allLanguages;
 	for (list<Dictionary>::iterator i = dictList.begin(); i != dictList.end(); ++i) {
-		allLanguages.insert((*i).getLanguage().getLanguage());
+		Dictionary d = *i;
+		if ((capability == CAPABILITY_SPELL && d.getSpellBackend().isAdvertised()) ||
+		    (capability == CAPABILITY_HYPHENATION && d.getHyphenatorBackend().isAdvertised()) ||
+		    (capability == CAPABILITY_GC && d.getGrammarBackend().isAdvertised())) {
+			allLanguages.insert(getShortLangForCapabilityFilteredList(d.getLanguage()));
+		}
 	}
 	
 	char ** languages = new char*[allLanguages.size() + 1];
@@ -92,6 +119,18 @@ VOIKKOEXPORT char ** voikkoListSupportedSpellingLanguages(const char * path) {
 	return languages;
 }
 
+VOIKKOEXPORT char ** voikkoListSupportedSpellingLanguages(const char * path) {
+	return listSupportedLanguagesForCapability(path, CAPABILITY_SPELL);
+}
+
+VOIKKOEXPORT char ** voikkoListSupportedHyphenationLanguages(const char * path) {
+	return listSupportedLanguagesForCapability(path, CAPABILITY_HYPHENATION);
+}
+
+VOIKKOEXPORT char ** voikkoListSupportedGrammarCheckingLanguages(const char * path) {
+	return listSupportedLanguagesForCapability(path, CAPABILITY_GC);
+}
+
 VOIKKOEXPORT const char * voikkoGetVersion() {
 	#ifdef PACKAGE_VERSION
 		return PACKAGE_VERSION;
